#!/bin/bash
perldoc -oHTML -ddocs/connector.html WebService::Hexonet::Connector
perldoc -oHTML -ddocs/hexonet.html WebService::Hexonet
perldoc -oHTML -ddocs/util.html WebService::Hexonet::Connector::Util
perldoc -oHTML -ddocs/connection.html WebService::Hexonet::Connector::Connection
perldoc -oHTML -ddocs/response.html WebService::Hexonet::Connector::Response
